==> docx4j-openxml-objects-8.3.2-sources.jar: org/docx4j/com/microsoft/schemas/office/drawing/x2014/chartex/CTStatistics.java <==

package org.docx4j.com.microsoft.schemas.office.drawing.x2014.chartex;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;;


/**
 * <p>Java class for CT_Statistics complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Statistics"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="quartileMethod" type="{http://schemas.microsoft.com/office/drawing/2014/chartex}ST_QuartileMethod" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Statistics")
public class CTStatistics implements Child
{

    @XmlAttribute(name = "quartileMethod")
    protected STQuartileMethod quartileMethod;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the quartileMethod property.
     * 
     * @return
     *     possible object is
     *     {@link STQuartileMethod }
     *     
     */
    public STQuartileMethod getQuartileMethod() {
        return quartileMethod;
    }

    /**
     * Sets the value of the quartileMethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link STQuartileMethod }
     *     
     */
    public void setQuartileMethod(STQuartileMethod value) {
        this.quartileMethod = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-8.3.10-sources.jar: org/docx4j/com/microsoft/schemas/office/drawing/x2014/chartex/CTStatistics.java <==

package org.docx4j.com.microsoft.schemas.office.drawing.x2014.chartex;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CT_Statistics complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Statistics"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="quartileMethod" type="{http://schemas.microsoft.com/office/drawing/2014/chartex}ST_QuartileMethod" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Statistics")
public class CTStatistics {

    @XmlAttribute(name = "quartileMethod")
    protected STQuartileMethod quartileMethod;

    /**
     * Gets the value of the quartileMethod property.
     * 
     * @return
     *     possible object is
     *     {@link STQuartileMethod }
     *     
     */
    public STQuartileMethod getQuartileMethod() {
        return quartileMethod;
    }

    /**
     * Sets the value of the quartileMethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link STQuartileMethod }
     *     
     */
    public void setQuartileMethod(STQuartileMethod value) {
        this.quartileMethod = value;
    }

}
